@@ -1,11 +1,10 @@
 import codecs
 import re
 from pathlib import Path
-from typing import Iterator, Match, Optional
+from typing import Optional
 
 import arrow
 import yaml
-from bs4 import BeautifulSoup
 
 from .helpers import fix_absent_signer_problem, fix_multiple_sections_in_first
 
@@ -136,11 +135,19 @@ def get_details(loc: Path) -> Optional[dict]:
         return None
 
 
-def add_old(filename: Path, data: dict) -> dict:
+def get_sections(filename: Path) -> dict:
+    """The existence of the path having been previously verified, this implies
+    prior processing from the `dblegacy` library which produces a yaml file
+    whose contents are in list format.
+
+    Args:
+        filename (Path): The legacy file
+
+    Returns:
+        dict: The list of section data, populated from the legacy file.
+    """
     with open(filename, "r") as r:
-        result = yaml.load(r, Loader=yaml.FullLoader)
-        data["units"] = result["units"]
-        return data
+        return yaml.load(r, Loader=yaml.FullLoader)
 
 
 def add_units(loc: Path, data: dict) -> Optional[dict]:
@@ -209,7 +216,8 @@ def load_statute(loc: Path) -> Optional[dict]:
 
     legacy_file = get_legacy_file(loc, data["category"])
     if legacy_file.exists():
-        return add_old(legacy_file, data)
+        data["units"] = get_sections(legacy_file)
+        return data
     else:
         return add_units(loc, data)
 
@@ -240,21 +248,31 @@ def get_directory(
 
 
 def get_title(category: str, num: str):
-    if category == "ra":
+    category_text = None
+    if category.lower() == "ra":
         category_text = "Republic Act No."
-    elif category == "eo":
+    elif category.lower() == "eo":
         category_text = "Executive Order No."
-    elif category == "pd":
+    elif category.lower() == "pd":
         category_text = "Presidential Decree No."
-    elif category == "bp":
+    elif category.lower() == "bp":
         category_text = "Batas Pambansa Blg."
-    elif category == "ca":
+    elif category.lower() == "ca":
         category_text = "Commonwealth Act No."
-    elif category == "act":
+    elif category.lower() == "act":
         category_text = "Act No."
-    elif category == "const":
+    elif category.lower() == "bm":
+        category_text = "Bar Matter No."
+    elif category.lower() == "am":
+        category_text = "Administrative Matter No."
+    elif category.lower() == "const":
         category_text = num
         num = "Constitution"
+    elif category.lower() == "es":
+        category_text = num
+        num = "Spanish"
+    else:
+        return None
     return f"{category_text} {num}"
 
 
@@ -300,14 +318,23 @@ def map_to_model(law_category: str, source: dict) -> Optional[dict]:
     """
     for field in ["numeral", "law_title", "date", "units"]:
         if not source.get(field, None):
+            print(f"Missing field: {field=}")
             return None
 
     # The database limit should be less than 1000 characters
     if len(source["law_title"]) > 1000:
         source["law_title"] = source["law_title"][:1000]
 
+    if not (title_text := get_title(law_category, source["numeral"])):
+        print(
+            f"Could not create title text with {law_category=} and {source['numeral']=}"
+        )
+        return None
+
     return {
-        "title": get_title(law_category, source["numeral"]),
+        "category": source["category"],
+        "identifier": source["numeral"],
+        "title": title_text,
         "full_title": source["law_title"],
         "specified_date": arrow.get(source["date"], "MMMM D, YYYY").date(),
         "publications": source.get("publications", None),
@@ -330,8 +357,8 @@ def get_statute(parent: Path, child: Path, context: str) -> Optional[dict]:
     Returns:
         Optional[dict]: [description]
     """
-    # Is the folder digit-like, e.g. 209 or 209-A
-    if not re.search(r"(^\d+-[A-C]$)|(^\d+$)", child.name):
+    # Is the folder digit-like, e.g. 209 or 209-A or 12-34-SC
+    if not re.search(r"(^\d+-[A-C]$)|(^\d+$)|[a-zA-Z0-9-]+", child.name):
         print(f"Not digit-like: {child}")
         return None
 
